classdef Ofr < handle
    %OFR Creates OFR class
    %   Calculates the residence time mean and peak values when assigning
    %   the transfer function.
    %   Pauli Simonen, Tampere University, 2023
    
    properties (SetAccess=protected, GetAccess=public)
        name
        rtd
        t_peak
        t_mean
    end
    
    methods
        function obj = Ofr(name)
            %OFR Construct an instance of this class
            if(contains(name, ' '))
                error('OFR name must not contain white space.');
            end
            obj.name = name;
        end
        function setRtd(obj, rtd)
            % RTD must correspond to 1 Hz time vector!
            if(sum(rtd) > 1.001 || sum(rtd) < 0.999)
                warning(['OFR (''' obj.name ''') RTD is not normalized. Normalizing now.']);
                rtd = rtd./sum(rtd);
            end
            obj.rtd = rtd;
            [~, obj.t_peak] = max(rtd);
            t = 0:1:numel(rtd)-1;
            obj.t_mean = round(sum(t.*rtd));
            disp(['OFR (''' obj.name ''') has peak residence time of ' num2str(obj.t_peak) ' s and mean residence of ' num2str(obj.t_mean) ' s.']);
        end
    end
end

