% Example of creating a Cycle class, an OFR class and simulating the
% driving cycle gas concentrations downstream of the OFR.
%   Pauli Simonen, Tampere University, 2023

c.time = (1:1:100)';
c.hc_ppm = zeros(size(c.time));
c.hc_ppm(10:20) = 10;
c.co2_percent = 5.*ones(size(c.time));
c.exhFlow_m3_per_s = 1e-3.*ones(size(c.time));
c.speed = NaN;
soaYield = 0.15;
endBufferLength = 600;

cycle = Cycle('A', c, soaYield, endBufferLength);

dofr = Ofr('DOFR');
dofr.setRtd(calcDofrRtd('low',700));

cycle.addOfr(dofr);

figure;
plot(cycle.original.tailpipe.hc_ppm);
hold on;
plot(cycle.DOFR.tailpipe.hc_ppm);
plot(cycle.DOFR.tailpipe.hc_ppm_shifted);
xlim([0 200]);