function [accelerations, idles, constSpeeds, decelerations] = binCycleData(time,speed)
%BINCYCLEDATA Divides NEDC into different driving conditions
%   Pauli Simonen, Tampere University, 2023

minDuration = 11;

%% Calculate accelerations
isConstant = NaN(size(time));
acceleration = NaN(size(time));
for k=1:numel(time)-1
    nextSpeed = speed(find(time > time(k),1,'first'));
    acceleration(k) = nextSpeed-speed(k);
    if(acceleration(k) == 0)
        isConstant(k) = true;
    else
        isConstant(k) = false;
    end
end
isConstant(end) = true;

%% Find idle periods:
idles = struct;
zeroSpeedIxs = find(speed < 0.01);
idleStarted = false;
ix = 1;
for k=1:numel(zeroSpeedIxs)
    if(~idleStarted)
        idles.startIx(ix,1) = time(zeroSpeedIxs(k));
        idleStarted = true;
        continue;
    end

    if(zeroSpeedIxs(k) == zeroSpeedIxs(k-1)+1)
        continue;
    end

    idles.endIx(ix,1) = time(zeroSpeedIxs(k-1));
    idleStarted = false;
    ix = ix + 1;
    % k = k-1;
end
if(numel(idles.endIx) ~= numel(idles.startIx))
    idles.endIx(end+1) = time(end);
end
% Add some buffer
idles.startIx(2:end) = idles.startIx(2:end) + 4;
if(idles.endIx(end) == time(end))
    idles.endIx(1:end-1) = idles.endIx(1:end-1) - 3;
else
    idles.endIx(1:end) = idles.endIx(1:end) - 3;
end
% Discard too short periods:
durations = zeros(size(idles.startIx));
for k=1:numel(idles.startIx)
    durations(k,1) = idles.endIx(k)-idles.startIx(k);
end
idles.startIx(durations < minDuration) = [];
idles.endIx(durations < minDuration) = [];
% Discard first idle if it's in the cycle begins with that:
if(idles.startIx == time(1))
    idles.startIx(1) = [];
    idles.endIx(1) = [];
end

%% Find constant speed periods:
constSpeeds = struct;
constSpeedIxs = find(isConstant & speed > 0);

% Remove duplicates:
toRemove = false(size(constSpeedIxs));
for k=2:numel(constSpeedIxs)
    if(time(constSpeedIxs(k)) == time(constSpeedIxs(k-1)))
        toRemove(k-1) = true;
    end
end
constSpeedIxs(toRemove) = [];

constSpeeds.startIx = time(constSpeedIxs);
for k=1:numel(constSpeeds.startIx)
    constSpeeds.endIx(k,1) = time(find(time > constSpeeds.startIx(k),1,'first'));
end

% Add some buffer
constSpeeds.startIx(2:end) = constSpeeds.startIx(2:end) + 6;
if(constSpeeds.endIx(end) == time(end))
    constSpeeds.endIx(1:end-1) = constSpeeds.endIx(1:end-1) - 4;
else
    constSpeeds.endIx(1:end) = constSpeeds.endIx(1:end) - 4;
end
% Discard too short periods:
durations = zeros(size(constSpeeds.startIx));
for k=1:numel(constSpeeds.startIx)
    durations(k,1) = constSpeeds.endIx(k)-constSpeeds.startIx(k);
end
constSpeeds.startIx(durations < minDuration) = [];
constSpeeds.endIx(durations < minDuration) = [];



%% Find acceleration periods:
accelerations = struct;
accIxs= find(~isConstant & acceleration > 0);

% Remove duplicates:
toRemove = false(size(accIxs));
for k=2:numel(accIxs)
    if(time(accIxs(k)) == time(accIxs(k-1)))
        toRemove(k-1) = true;
    end
end
accIxs(toRemove) = [];

accelerations.startIx = time(accIxs);
for k=1:numel(accelerations.startIx)
    accelerations.endIx(k,1) = time(find(time > accelerations.startIx(k),1,'first'));
end

% Remove duplicates:
toRemove = false(size(accelerations.startIx));
for k=2:numel(accelerations.startIx)
    if(accelerations.startIx(k) == accelerations.endIx(k-1))
        accelerations.startIx(k) = accelerations.startIx(k-1);
        toRemove(k-1) = true;
    end
end
accelerations.startIx(toRemove) = [];
accelerations.endIx(toRemove) = [];

% Add some buffer
accelerations.startIx = accelerations.startIx - 1;
accelerations.endIx = accelerations.endIx + 2;


%% Find deceleration periods:
decelerations = struct;
decIxs = find(~isConstant & acceleration < 0);

% Remove duplicates:
toRemove = false(size(decIxs));
for k=2:numel(decIxs)
    if(time(decIxs(k)) == time(decIxs(k-1)))
        toRemove(k-1) = true;
    end
end
decIxs(toRemove) = [];

decelerations.startIx = time(decIxs);
for k=1:numel(decelerations.startIx)
    decelerations.endIx(k,1) = time(find(time > decelerations.startIx(k),1,'first'));
end

% Remove duplicates:
toRemove = false(size(decelerations.startIx));
for k=2:numel(decelerations.startIx)
    if(decelerations.startIx(k) == decelerations.endIx(k-1))
        decelerations.startIx(k) = decelerations.startIx(k-1);
        toRemove(k-1) = true;
    end
end
decelerations.startIx(toRemove) = [];
decelerations.endIx(toRemove) = [];

% Add some buffer
decelerations.startIx = decelerations.startIx - 2;
decelerations.endIx = decelerations.endIx + 2;


end

