function [b, statsStruct] = boxchart_ps(dataTable,color,varargin)
%BOXCHART_PS Box plot with simply defined outliers
%   Pauli Simonen, Tampere University, 2023

if(nargin == 2)
    whiskerWidth = 1.0;
    upperPrctile = 99;
    lowerPrctile = 1;
elseif(nargin == 3)
    whiskerWidth = varargin{1};
    upperPrctile = 99;
    lowerPrctile = 1;
elseif(nargin == 4)
    whiskerWidth = varargin{1};
    lowerPrctile = varargin{2}(1);
    upperPrctile = varargin{2}(2);
elseif(nargin < 2)
    error('Too few input arguments.');
else
    error('Too many input arguments.');
end

if(strcmpi(color,'blue'))
    faceColor = [0 0.4470 0.7410];
    edgeColor = [0 0.4470 0.741];
    medianLineColor = [0 0.4470 0.741];
    markerColor = [0 0.4470 0.741];
elseif(strcmpi(color,'red'))
    faceColor = [0.8500 0.3250 0.0980];
    edgeColor = [0.8500 0.3250 0.0980];
    medianLineColor = [0.8500 0.3250 0.0980];
    markerColor = [0.8500 0.3250 0.0980];
else
    error('Unknown color.');
end

xVals = unique(dataTable.x);

b = boxchart(dataTable.x,dataTable.values);
b.MarkerStyle = 'none';
b.WhiskerLineStyle = 'none';
b.BoxFaceColor = faceColor;
b.BoxMedianLineColor = medianLineColor;
b.BoxEdgeColor = edgeColor;
b.BoxWidth = whiskerWidth;
hold on;

for k=1:numel(xVals)
    allData = dataTable.values(dataTable.x > xVals(k)-0.1 & dataTable.x < xVals(k)+0.1);
    upperWhisker = prctile(allData,upperPrctile);
    lowerWhisker = prctile(allData,lowerPrctile);
    upperBox = quantile(allData,0.75);
    lowerBox = quantile(allData,0.25);
    outliers = allData(allData > upperWhisker | allData < lowerWhisker);
    upperWhisker = max(allData(allData < upperWhisker));
    lowerWhisker = min(allData(allData > lowerWhisker));
    statsStruct.median(1,k) = median(allData);
    statsStruct.p01(1,k) = lowerWhisker;
    statsStruct.p99(1,k) = upperWhisker;
    statsStruct.p25(1,k) = lowerBox;
    statsStruct.p75(1,k) = upperBox;
    % Outliers
    if(numel(outliers) > 8)
        % For a large number of outliers, scatter them across the box
        % width:
        outlierXs = randb((xVals(k)-whiskerWidth*b.BoxWidth/2).*ones(numel(outliers),1),(xVals(k)+whiskerWidth*b.BoxWidth/2).*ones(numel(outliers),1));
        hs = scatter(outlierXs,outliers,1,'o','MarkerFaceColor',markerColor,'MarkerEdgeColor','none');
        hs.MarkerFaceAlpha = 0.2;
        % hs.MarkerEdgeAlpha = 0.2;
    else
        outlierXs = xVals(k).*ones(numel(outliers),1);
        plot(outlierXs,outliers,'.','Color',markerColor);
    end


    % Whisker vertical lines:
    line([xVals(k) xVals(k)],[upperBox upperWhisker],'LineWidth',1,'Color','k');
    line([xVals(k) xVals(k)],[lowerBox lowerWhisker],'LineWidth',1,'Color','k');
    % Whisker horizontal lines:
    line([xVals(k)-whiskerWidth*b.BoxWidth/2 xVals(k)+whiskerWidth*b.BoxWidth/2], [upperWhisker upperWhisker],'LineWidth',1,'Color','k');
    line([xVals(k)-whiskerWidth*b.BoxWidth/2 xVals(k)+whiskerWidth*b.BoxWidth/2], [lowerWhisker lowerWhisker],'LineWidth',1,'Color','k');

end

end

