function [rtd,tResMean,tResPeak, stdev] = calcDofrRtd(uvLampSetting,timeLength)
%CALCDOFRRTD Calculates DOFR transfer function
%   Pauli Simonen, Tampere University, 2023

if(strcmpi(uvLampSetting,'low'))
    Pe1 = 59.9304;
    tau1 = 27.1867;
    f1 = 0.5438;
    Pe2 = 13.9073;
    tau2 = 49.9008;
    f2 = 0.4562;
else
    error('Unknown UV lamp setting');
end

t = 1:1:timeLength;


E1 = f1./2.*sqrt(Pe1./(pi.*tau1.*t)).*exp(-(Pe1.*(tau1-t).^2)./(4.*tau1.*t));
E2 = f2./2.*sqrt(Pe2./(pi.*tau2.*t)).*exp(-(Pe2.*(tau2-t).^2)./(4.*tau2.*t));
E = E1+E2;
E = E./sum(E); % Unnecessary if f1+f2 = 1.
rtd = E;
[~,tResPeak] = max(E);
tResMean_raw = sum(t.*E);
tResMean = round(sum(t.*E));

stdev = sqrt(sum((t-tResMean_raw).^2.*E));

end






