function [rtd,tResMean,tResPeak, stdev] = calcPamRtd(timeLength)
%CALCPAMRTD Calculates PAM transfer function
%   Pauli Simonen, Tampere University, 2023

tres1 = 33.7762;
tres2 = 59.6120;
tres3 = 159.0658;
Pe1 = 31.8016;
Pe2 = 9.8594;
Pe3 = 6.5239;
f1 = 0.1357;
f2 = 0.3098;
f3 = 0.5545;

t = 1:1:timeLength;

tau1 = t./tres1;
tau2 = t./tres2;
tau3 = t./tres3;

E1 = f1./2.*sqrt(Pe1./(pi.*tres1.*t)).*exp(-(Pe1.*(tres1-t).^2)./(4.*tres1.*t));
E2 = f2./2.*sqrt(Pe2./(pi.*tres2.*t)).*exp(-(Pe2.*(tres2-t).^2)./(4.*tres2.*t));
E3 = f3./2.*sqrt(Pe3./(pi.*tres3.*t)).*exp(-(Pe3.*(tres3-t).^2)./(4.*tres3.*t));

E = E1+E2+E3;
E = E./sum(E); % Normalize, unnecessary if f1+f2+f3 = 1.

rtd = E;
[~,tResPeak] = max(E);
tResMean_raw = sum(t.*E);
tResMean = round(sum(t.*E));

stdev = sqrt(sum((t-tResMean_raw).^2.*E));
end

