function [ofrStruct,cycleStruct] = handleBinnedData(cycle,binData,calculationMethod)
%HANDLEBINNEDDATA Calculates SOA PF for each bin in 'binData' for the
%driving cycle 'cycle'.
%   Pauli Simonen, Tampere University, 2023

ofrs = cycle.ofrNames;

% Find the corresponding index for requested calculation method:
emissionIx = NaN;
for k=1:numel(cycle.(ofrs{1}).emissions)
    if(strcmp(cycle.(ofrs{1}).emissions{k}.method, calculationMethod))
        emissionIx = k;
        break;
    end
end
if(isnan(emissionIx))
    error(['Could not find calculation method ''' calculationMethod '''.']);
end

bins = fieldnames(binData);
[rows,cols] = size(bins);
if(rows > cols)
    bins = bins';
end

for bin=bins
    fieldname = bin{1};
    for j=1:numel(binData.(fieldname).startIx)
        cycleStruct.(fieldname).pf(j,1) = cycle.soaPfBetween(binData.(fieldname).startIx(j), binData.(fieldname).endIx(j),'original');
        cycleStruct.(fieldname).averagedPf(j,1) = mean(cycle.original.emissions.pf_mg_per_kgfuel(binData.(fieldname).startIx(j):binData.(fieldname).endIx(j)));
        cycleStruct.(fieldname).timeAvg(j,1) = mean([cycle.original.time(binData.(fieldname).startIx(j)), cycle.original.time(binData.(fieldname).endIx(j))]);
        for ofr=ofrs
            ofrStruct.(ofr{1}).(fieldname).pf(j,1) = cycle.soaPfBetween(binData.(fieldname).startIx(j), binData.(fieldname).endIx(j),ofr{1},calculationMethod);
            ofrStruct.(ofr{1}).(fieldname).averagedEf(j,1) = mean(cycle.(ofr{1}).emissions{emissionIx}.pf_mg_per_kgfuel(binData.(fieldname).startIx(j):binData.(fieldname).endIx(j)));
            ofrStruct.(ofr{1}).(fieldname).timeAvg(j,1) = cycleStruct.(fieldname).timeAvg(j,1);
        end
    end
end


