function [h] = plotBinPatches(time, bins, color, lineWidth, varargin)
%PLOTBINPATCHES Draws rectangles for each bin.
%   Pauli Simonen, Tampere University, 2023

if(nargin < 5)
    axH = gca;
else
    axH = varargin{1};
end

if(nargin > 5)
    error('Too many input arguments');
end

[rows, cols] = size(time);
if(rows > cols)
    time = time';
end

axes(axH);

ylims = ylim(axH);
maxY = ylims(2);
minY = ylims(1);

for k=1:numel(bins.startIx)
    ixStart = bins.startIx(k);
    ixEnd = bins.endIx(k);
    if(lineWidth < 0.01)
        h(k,1) = patch('XData',[time(ixStart), time(ixEnd) time(ixEnd) time(ixStart)],'YData',[maxY maxY minY minY],'ZData',-1.*[1 1 1 1],'FaceColor',color,'EdgeColor','none');
        % h(k,1) = patch('XData',[time(ixStart), time(ixEnd) time(ixEnd) time(ixStart)],'YData',[maxY maxY minY minY],'FaceColor',color,'EdgeColor','none');
    else
        % h(k,1) = patch('XData',[time(ixStart), time(ixEnd) time(ixEnd) time(ixStart)],'YData',[maxY maxY minY minY],'FaceColor',color,'EdgeColor','k','LineWidth',lineWidth);
        h(k,1) = patch('XData',[time(ixStart), time(ixEnd) time(ixEnd) time(ixStart)],'YData',[maxY maxY minY minY],'ZData',-1.*[1 1 1 1],'FaceColor',color,'EdgeColor','k','LineWidth',lineWidth);
    end
set(axH,'Layer','top');


end

