function [ N ] = ppmTo1Cm3( ppm, T )
%PPMTO1CM3 Converts ppm to molec./cm3
%   Pauli Simonen, Tampere University, 2023

if(T > 100)
    warning('Temperature input must be in celsius.');
end
T = T+273.15; % C to K
k = 1.3806488e-23; % Boltzmann constant
p = 101.325e3; % Normal pressure
V = 1e-6; % 1 cm3 converted to m3
Nair = (p.*V)./(k.*T);

N = Nair./1e6.*ppm;

end