%   Pauli Simonen, Tampere University, 2024
%%
isExport = true;

fs = 8; % Font size
widthCm = 16; % Figure width (cm)
heightCm = 6; % Figure height (cm)

%% Colors
blueC = [0 114 189]./255;
redC = [217 83 25]./255;
grayC = [0.3 0.3 0.3];


%% Distributions
hcDistLow = makedist('Normal','mu',1,'sigma',10);
hcDistLow = truncate(hcDistLow,0,10);
hcDistMedium = makedist('Normal','mu',30,'sigma',60);
hcDistMedium = truncate(hcDistMedium,15,200);
hcDistHigh = makedist('Normal','mu',1000,'sigma',1000);
hcDistHigh = truncate(hcDistHigh,500,4000);

co2DistGasoline = makedist('Normal','mu',13,'sigma',2);
co2DistGasoline = truncate(co2DistGasoline,3,14);
co2DistDiesel = makedist('Normal','mu',7,'sigma',6);
co2DistDiesel = truncate(co2DistDiesel,1,14);

cc = createRandomCycle(co2DistGasoline,co2DistDiesel,hcDistLow,hcDistMedium,hcDistHigh);
while(numel(cc.time) < 1100 || numel(cc.time) > 1400 || cc.isDiesel) % Gasoline example with long enough duration
    cc = createRandomCycle(co2DistGasoline,co2DistDiesel,hcDistLow,hcDistMedium,hcDistHigh);
end
%%
fh = figure;
fh.Units = 'centimeters';
fh.Position(3) = widthCm;
fh.Position(4) = heightCm;
fh.Color = 'w';

plot(cc.co2_percent,'LineWidth',1.5,'Color',grayC);
hold on;
plot(cc.hc_ppm./10, 'LineWidth', 1.5, 'Color', blueC);
grid on;
ylabel('CO_2 (%), HC (ppm/10)');
set(gca,'FontSize',fs);
yyaxis right;
plot(cc.exhFlow_m3_per_s,'LineWidth',1.5,'Color',redC);
ylabel('Q_{exh} (m^3 s^{-1})');
set(gca,'YColor','k');
legh = legend('CO_2','HC','Q_{exh}','Location','NorthEast');
legh.BoxFace.ColorType = 'truecoloralpha';
legh.BoxFace.ColorData=uint8(255*[1 1 1 0.9]');
ylim([0 0.2]);
set(gca,'FontSize',fs);
xlabel('Time (s)');

if(isExport)
    exportgraphics(gcf,'./exportedFigures/fig8.pdf');
end