%   Pauli Simonen, Tampere University, 2023
%%
isSave = true; % Save the simulated cycles?
isExport = true;

blueC = [0.00,0.45,0.74];
redC = [0.85,0.33,0.10];
fs = 8; % Font size
lw = 1.2; % Line width
widthCm = 16; % Figure width (cm)
heightCm = 7; % Figure height (cm)

%% Create/load synthetic cycles
file2load = './data/monteCarlo/mc_2023_10_26_20_18_n10000.mat';

if(~isfile(file2load))
    disp('Pre-calculated synthetic data not found.');
    numCycles = 10000;
    o = createMonteCarloData(numCycles);
    
    if(isSave)
        fnam = ['mc_' datestr(now(), 'yyyy_mm_dd_HH_MM') '_n' num2str(numCycles)];
        save(['./data/monteCarlo/' fnam '.mat'],'o');
        disp(['File ./data/monteCarlo/' fnam '.mat saved.']);
    end
else
    disp('Loading the synthetic data...');
    o = load(file2load);
    o = o.o;
    disp('Synthetic data loaded.');
end


%% Extract data from simulations:
d = struct;
p = struct;
d.p01 = NaN(size(o.percentileIntervals));
d.p25 = NaN(size(o.percentileIntervals));
d.p75 = NaN(size(o.percentileIntervals));
d.p99 = NaN(size(o.percentileIntervals));
p.p01 = NaN(size(o.percentileIntervals));
p.p25 = NaN(size(o.percentileIntervals));
p.p75 = NaN(size(o.percentileIntervals));
p.p99 = NaN(size(o.percentileIntervals));
for k=1:numel(o.percentileIntervals)
    d.p01(k) = prctile(o.dofrPrctiles{k},1);
    d.p25(k) = prctile(o.dofrPrctiles{k},25);
    d.p75(k) = prctile(o.dofrPrctiles{k},75);
    d.p99(k) = prctile(o.dofrPrctiles{k},99);

    p.p01(k) = prctile(o.pamPrctiles{k},1);
    p.p25(k) = prctile(o.pamPrctiles{k},25);
    p.p75(k) = prctile(o.pamPrctiles{k},75);
    p.p99(k) = prctile(o.pamPrctiles{k},99);
end

%% Plot
fh = figure;
fh.Units = 'centimeters';
fh.Position(3) = widthCm;
fh.Position(4) = heightCm;
fh.Color = 'w';

t = tiledlayout(1,2);
t.Padding = 'none';
t.TileSpacing = 'compact';

nexttile;
plot(o.percentileIntervals,10.^d.p99,'s-','Color',blueC,'LineWidth',lw)
hold on
plot(o.percentileIntervals,10.^d.p25,'o-','Color',redC,'LineWidth',lw)
plot(o.percentileIntervals,10.^d.p01,'s-','Color',blueC,'LineWidth',lw)
plot(o.percentileIntervals,10.^d.p75,'o-','Color',redC,'LineWidth',lw)
title('DOFR');
set(gca,'TitleFontWeight','normal');
set(gca,'TitleFontSizeMultiplier',1.0);
grid on;
xlabel('Bin duration (s)');
legend('1st and 99th percentiles','25th and 75th percentiles','Location','NorthEast');
ax1 = gca;
ax1.YLabel.Interpreter = 'latex';               
ax1.YLabel.String = '$\frac{\rm Reactor\ PF}{\rm Reference\ PF}$';
set(gca,'FontSize',fs);
set(gca,'XTick',[1 100:100:o.percentileIntervals(end)]);
set(gca,'YScale','log');

nexttile;
plot(o.percentileIntervals,10.^p.p99,'s-','Color',blueC,'LineWidth',lw)
hold on
plot(o.percentileIntervals,10.^p.p25,'o-','Color',redC,'LineWidth',lw)
plot(o.percentileIntervals,10.^p.p01,'s-','Color',blueC,'LineWidth',lw)
plot(o.percentileIntervals,10.^p.p75,'o-','Color',redC,'LineWidth',lw)
title('PAM');
set(gca,'TitleFontWeight','normal');
set(gca,'TitleFontSizeMultiplier',1.0);
grid on;
xlabel('Bin duration (s)');
legend('1st and 99th percentiles','25th and 75th percentiles','Location','NorthEast');
ax2 = gca;
ax2.YLabel.Interpreter = 'latex';               
ax2.YLabel.String = '$\frac{\rm Reactor\ PF}{\rm Reference\ PF}$';
set(gca,'FontSize',fs);
set(gca,'XTick',[1 100:100:o.percentileIntervals(end)]);
set(gca,'YScale','log');
ylims = ylim;

ax1.YLim = ylims;

%% Export pdf:
if(isExport)
    exportgraphics(gcf,'./exportedFigures/figS12.pdf');
end
clear isExport

%% Clear workspace
clear ax1 ax2 blueC redC d fh file2load fs heightCm isSave k lw o p;
clear t widthCm ylims;