%   Pauli Simonen, Tampere University, 2023
%% Constants
isExport = true;
fs = 8; % Font size
widthCm = 16; % Figure width (cm)
heightCm = 7; % Figure height (cm)
lw = 0.3;

%% Divide NEDC cycle into bins
% Load theoretical speed and adjust time to match recorded speed:
load ./data/nedcSpeed.mat nedcSpeed
nedcSpeed.time = nedcSpeed.time + 1;

bins = struct;
[bins.accelerations, bins.idles, bins.constSpeeds, bins.decelerations] =...
    binCycleData(nedcSpeed.time, nedcSpeed.speed);
time=(1:1:nedcSpeed.time(end))';

%% Plot
fh = figure;
fh.Units = 'centimeters';
fh.Position(3) = widthCm;
fh.Position(4) = heightCm;
fh.Color = 'w';
fh.Renderer = 'painters';

colorAcc = [1 0.43 0.33];
colorConst = [0.87 0.67 1];
colorIdle = [0.64 1 0.52];
colorDec = [0.30 0.75 0.93];

hs = plot(nedcSpeed.time,nedcSpeed.speed,'LineWidth',1.0,'Color','k');
hAcc = plotBinPatches(time,bins.accelerations,colorAcc,lw);
hIdle = plotBinPatches(time,bins.idles,colorIdle,lw);
hConst = plotBinPatches(time,bins.constSpeeds,colorConst,lw);
hDec = plotBinPatches(time,bins.decelerations,colorDec,lw);
xlim([0 1200])
legend([hs,hIdle(1),hConst(1),hAcc(1),hDec(1)],'Speed','Idle','Constant speed','Acceleration','Deceleration','Location','North');
ylabel('Speed (km h^{-1})');
xlabel('Time (s)');
set(gca,'FontSize',fs);

%% Export pdf:
if(isExport)
    exportgraphics(gcf,'./exportedFigures/figS14.pdf');
end
clear isExport

%% Clear workspace
clear bins colorAcc colorConst colorDec colorIdle fh fs hAcc hConst;
clear hDec heightCm hIdle hs lw nedcSpeed time widthCm;